#[non_exhaustive]pub struct CreateCapacityReservationInput {
pub target_dpus: Option<i32>,
pub name: Option<String>,
pub tags: Option<Vec<Tag>>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.target_dpus: Option<i32>The number of requested data processing units.
name: Option<String>The name of the capacity reservation to create.
The tags for the capacity reservation.
Implementations
Sourceimpl CreateCapacityReservationInput
impl CreateCapacityReservationInput
Sourcepub fn target_dpus(&self) -> Option<i32>
pub fn target_dpus(&self) -> Option<i32>
The number of requested data processing units.
The tags for the capacity reservation.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .tags.is_none().
Sourceimpl CreateCapacityReservationInput
impl CreateCapacityReservationInput
Sourcepub fn builder() -> CreateCapacityReservationInputBuilder
pub fn builder() -> CreateCapacityReservationInputBuilder
Creates a new builder-style object to manufacture CreateCapacityReservationInput.